@@ -53,7 +53,7 @@ void qpdf_basic_settings(QPDF &q) // LCOV_EXCL_LINE
     q.setLogger(get_pikepdf_logger());
 }
 
-std::unique_ptr<QPDF> open_pdf(py::object filename_or_stream,
+std::shared_ptr<QPDF> open_pdf(py::object filename_or_stream,
     std::string password,
     bool hex_password            = false,
     bool ignore_xref_streams     = false,
@@ -62,7 +62,7 @@ std::unique_ptr<QPDF> open_pdf(py::object filename_or_stream,
     bool inherit_page_attributes = true,
     access_mode_e access_mode    = access_mode_e::access_default)
 {
-    auto q = std::make_unique<QPDF>();
+    auto q = std::make_shared<QPDF>();
 
     qpdf_basic_settings(*q);
     q->setSuppressWarnings(suppress_warnings);
@@ -519,16 +519,28 @@ void init_qpdf(py::module_ &m)
         .value("mmap", access_mode_e::access_mmap)
         .value("mmap_only", access_mode_e::access_mmap_only);
 
-    py::class_<QPDF>(m, "Pdf", "In-memory representation of a PDF", py::dynamic_attr())
+    py::class_<QPDF, std::shared_ptr<QPDF>>(
+        m, "Pdf", "In-memory representation of a PDF", py::dynamic_attr())
         .def_static(
             "new",
             []() {
-                auto q = std::make_unique<QPDF>();
+                auto q = std::make_shared<QPDF>();
                 q->emptyPDF();
                 qpdf_basic_settings(*q);
                 return q;
             },
-            "Create a new empty PDF from scratch.")
+            R"~~~(
+            Create a new, empty PDF.
+
+            This is best when you are constructing a PDF from scratch.
+
+            In most cases, if you are working from an existing PDF, you should open the
+            PDF using :meth:`pikepdf.Pdf.open` and transform it, instead of a creating
+            a new one, to preserve metadata and structural information. For example,
+            if you want to split a PDF into two parts, you should open the PDF and
+            transform it into the desired parts, rather than creating a new PDF and
+            copying pages into it.
+            )~~~")
         .def_static("_open",
             open_pdf,
             py::arg("filename_or_stream"),
@@ -565,7 +577,7 @@ void init_qpdf(py::module_ &m)
             )~~~")
         .def_property_readonly(
             "pages",
-            [](QPDF &q) { return PageList(q); },
+            [](std::shared_ptr<QPDF> q) { return PageList(q); },
             R"~~~(
             Returns the list of pages.
 
